import re

from mask_util.const import KEYWORDS
from replacer import Replacer


def mask_keyword(input: str) -> str:
    """
        按照关键词对文本进行脱敏。
        支持的格式：
            password = "123456"
            map.put("password", "123456")
            {
                "password": "123456"
            }
    :param input: 要脱敏的文本
    :return: 脱敏后的文本
    """
    replacement: str = "***"
    replacer = Replacer(replacement)
    masked_input: str = input
    for keyword in KEYWORDS:
        pattern = r"([\"']?" + keyword + "[\"']?\s*[,:]\s*[\"']?|" + keyword + "\s*=\s*[\"']?)([^\"']*)([\"']?)"
        masked_input = re.sub(pattern, replacer.replacement, masked_input)
    return masked_input



from re import Match


class Replacer:
    def __init__(self, replace_str: str):
        self.replace_str = replace_str

    def replacement(self, match: Match):
        group1 = match.group(1)
        group2 = self.replace_str
        group3 = match.group(3)
        return f'{group1}{group2}{group3}'



# Ãô¸Ð¹Ø¼ü×Ö
from typing import List

KEYWORDS: List[str] = ["password", "passwd", "token", "authorized_token", "access_token",
                "security_token", "username", "user_name", "uname", "login", "logout", "ip", "ip_address", "ip_add",
                "domain", "internal_domain", "realm"]



import setuptools

with open("README.md", "r") as fh:
  long_description = fh.read()

setuptools.setup(
  name="mask_util",
  version="0.0.5",
  author="chenqixian",
  install_requires=[],
  description="a package to mask data",
  long_description=long_description,
  long_description_content_type="text/markdown",
  packages=setuptools.find_packages(),
  python_requires='>=3.6',
  license="Apache License, Version 2.0",
)